/*
 * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
 * @license AGPL-3.0
 *
 * This code is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OX App Suite. If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
 *
 * Any use of the work other than as authorized under this license or copyright law is prohibited.
 *
 */

package com.openexchange.office.filter.api;

import java.util.Collections;
import java.util.HashMap;
import java.util.Map;

public enum OCKey {

    AC("ac", null),
    ACTIVE_CELL("activeCell", null),
    ACTIVE_INDEX("activeIndex", null),
    ACTIVE_PANE("activePane", null),
    ACTIVE_SHEET("activeSheet", null),
    AH_LIST("ahList", null),
    ALIGN("align", null),
    ALIGN_HOR("alignHor", null),
    ALIGN_VERT("alignVert", null),
    ALIGNMENT("alignment", null),
    ALT_NAMES("altNames", null),
    ANCHOR("anchor", null),
    ANCHOR_BEHIND_DOC("anchorBehindDoc", null),
    ANCHOR_CENTERED("anchorCentered", null),
    ANCHOR_HOR_ALIGN("anchorHorAlign", null),
    ANCHOR_HOR_BASE("anchorHorBase", null),
    ANCHOR_HOR_OFFSET("anchorHorOffset", null),
    ANCHOR_LAYER_ORDER("anchorLayerOrder", null),
    ANCHOR_NAME("anchorName", null),
    ANCHOR_VERT_ALIGN("anchorVertAlign", null),
    ANCHOR_VERT_BASE("anchorVertBase", null),
    ANCHOR_VERT_OFFSET("anchorVertOffset", null),
    ANG("ang", null),
    AP("ap", null),
    APPLY("apply", null),
    ASPECT_LOCKED("aspectLocked", null),
    ATTRS("attrs", "a"),
    AUTHOR_ID("authorId", null),
    AUTHOR_NAME("authorName", null),
    AUTHOR_PROVIDER("authorProvider", null),
    AUTHOR("author", null),
    AUTHORS("authors", null),
    AUTO_DATE_FIELD("autoDateField", null),
    AUTO_RESIZE_HEIGHT("autoResizeHeight", null),
    AUTO_RESIZE_TEXT("autoResizeText", null),
    AV_LIST("avList", null),
    AX_POS("axPos", null),
    AXIS("axis", null),
    AXIS_X_INDEX("axisXIndex", null),
    AXIS_Y_INDEX("axisYIndex", null),
    AXIS_Z_INDEX("axisZIndex", null),
    B("b", null),
    BACKGROUND_STYLE("backgroundStyle", null),
    BAND1_HORZ("band1Hor", null),
    BAND1_VERT("band1Vert", null),
    BAND2_HORZ("band2Hor", null),
    BAND2_VERT("band2Vert", null),
    BANDS_HOR("bandsHor", null),
    BANDS_VERT("bandsVert", null),
    BASE_COL_WIDTH("baseColWidth", null),
    BASE_STYLE_ID("baseStyleId", null),
    BASELINE("baseline", null),
    BC("bc", null),
    BITMAP("bitmap", null),
    BODY("body", null),
    BOLD("bold", null),
    BOLD_ASIAN("boldAsian", null),
    BOLD_COMPLEX("boldComplex", null),
    BORDER("border", null),
    BORDER_BOTTOM("borderBottom", null),
    BORDER_INSIDE("borderInside", null),
    BORDER_INSIDE_HOR("borderInsideHor", null),
    BORDER_INSIDE_VERT("borderInsideVert", null),
    BORDER_LEFT("borderLeft", null),
    BORDER_RIGHT("borderRight", null),
    BORDER_TOP("borderTop", null),
    BOTTOM("bottom", null),
    BOTTOM_LEFT("bottomLeft", null),
    BOTTOM_RIGHT("bottomRight", null),
    BUBBLE3D("bubble3d", null),
    BUBBLES("bubbles", null),
    BULLET("bullet", null),
    BULLET_COLOR("bulletColor", null),
    BULLET_FONT("bulletFont", null),
    BULLET_SIZE("bulletSize", null),
    C("c", null),
    CALC_ON_LOAD("calcOnLoad", null),
    CAPS("caps", null),
    CASE_SENSITIVE("caseSensitive", null),
    CELL("cell", null),
    CHANGE_TRACKING("changeTracking", null),
    CHANGES("changes", "cg"),
    CHARACTER("character", "ch"),
    CHART("chart", null),
    CHART_COLORS("chartColors", null),
    CHART_GROUP("chartGroup", null),
    CHART_PART("chartPart", null),
    CHART_STYLE_ID("chartStyleId", null),
    CHART_TYPE("chartType", null),
    CHART3D("chart3d", null),
    CHECKED("checked", null),
    CHILD_HEIGHT("childHeight", null),
    CHILD_LEFT("childLeft", null),
    CHILD_TOP("childTop", null),
    CHILD_WIDTH("childWidth", null),
    CHILDREN("children", null),
    CODE("code", null),
    COL("col", null),
    COL_TOTAL_BEFORE("colTotalBefore", null),
    COLLAPSE("collapse", null),
    COLLAPSED("collapsed", null),
    COLOR("color", null),
    COLOR_INDEX("colorIndex", null),
    COLOR_SCALE("colorScale", null),
    COLOR_SCHEME("colorScheme", null),
    COLOR_STOPS("colorStops", null),
    COLOR2("color2", null),
    COLS("cols", null),
    COLUMN("column", null),
    COLUMNS("columns", null),
    COMMANDS("commands", null),
    COMPARE("compare", null),
    CONNECTOR("connector", null),
    CONTENTS("contents", null),
    CONTEXTUAL_SPACING("contextualSpacing", null),
    COORD_HEIGHT("coordHeight", null),
    COORD_WIDTH("coordWidth", null),
    COUNT("count", null),
    CREATED("created", null),
    CROP_BOTTOM("cropBottom", null),
    CROP_LEFT("cropLeft", null),
    CROP_RIGHT("cropRight", null),
    CROP_TOP("cropTop", null),
    CROSS_AX("crossAx", null),
    CURVED("curved", null),
    CUSTOM("custom", null),
    CUSTOM_FORMAT("customFormat", null),
    CUSTOM_HEIGHT("customHeight", null),
    CUSTOM_PROMPT("customPrompt", null),
    CUSTOM_WIDTH("customWidth", null),
    CXN_LIST("cxnList", null),
    D("d", null),
    DATA_BAR("dataBar", null),
    DATA_LABEL("dataLabel", null),
    DATA_LABELS("dls", null),
    DATA_LABEL_POS("dlp", null),
    DATA_LABEL_POS_ABOVE("lba", null),
    DATA_LABEL_POS_BOTTOM("lbb", null),
    DATA_LABEL_POS_LEFT("lbl", null),
    DATA_LABEL_POS_RIGHT("lbr", null),
    DATA_LABEL_POS_CENTER("lbc", null),
    DATA_LABEL_POS_OUTSIDE("lbo", null),
    DATA_LABEL_POS_INSIDE("lbi", null),
    DATA_LABEL_POS_INSIDE_BASE("lbib", null),
    DATA_LABEL_POS_BEST_FIT("lbbf", null),
    DATA_LABEL_TEXT("dlt", null),
    DATA_POINTS("dataPoints", null),
    DATE("date", null),
    DEFAULT("default", null),
    DEFAULT_TAB_SIZE("defaultTabSize", null),
    DEFAULT_TABSTOP("defaultTabStop", null),
    DEFAULT_TEXT_LIST_STYLES("defaultTextListStyles", null),
    DESCENDING("descending", null),
    DESCRIPTION("description", null),
    DISPLAY_NAME("displayName", null),
    DIR("dir", null),
    DOCUMENT("document", null),
    DONE("done", null),
    DRAWING("drawing", "dr"),
    DRAWINGS("drawings", null),
    DXF("dxf", null),
    E("e", null),
    EFFECTS("effects", null),
    EMAIL("email", null),
    ENABLED("enabled", null),
    END("end", "q"),
    END_COL_OFFSET_VML("endColOffsetVML", null),
    END_GRID("endGrid", null),
    END_ID("endId", null),
    END_INDEX("endIndex", null),
    END_ROW_OFFSET_VML("endRowOffsetVML", null),
    ENTRIES("entries", null),
    ERROR("error", null),
    ERROR_BAR("eb", null),
    ERROR_TEXT("errorText", null),
    ERROR_TITLE("errorTitle", null),
    ERROR_TYPE("errorType", null),
    EVEN_ODD_PAGES("evenOddPages", null),
    EXCLUDE("exclude", null),
    F("f", null),
    FALLBACK_VALUE("fallbackValue", null),
    FAMILY("family", null),
    FAMILY_GENERIC("familyGeneric", null),
    FIELD("field", null),
    FILE_FORMAT("fileFormat", null),
    FILL("fill", null),
    FILL_CHAR("fillChar", null),
    FILL_COLOR("fillColor", null),
    FILL_MODE("fillMode", null),
    FILL_TYPE("fillType", null),
    FILTER("filter", null),
    FILTERED("filtered", null),
    FIRST_COL("firstCol", null),
    FIRST_PAGE("firstPage", null),
    FIRST_ROW("firstRow", null),
    FLIP_H("flipH", null),
    FLIP_MODE("flipMode", null),
    FLIP_V("flipV", null),
    FOLLOW_MASTER_SHAPES("followMasterShapes", null),
    FOLLOW_TEXT("followText", null),
    FONT("font", null),
    FONT_NAME("fontName", null),
    FONT_NAME_ASIAN("fontNameAsian", "fna"),
    FONT_NAME_COMPLEX("fontNameComplex", "fnc"),
    FONT_NAME_EAST_ASIA("fontNameEastAsia", "fnea"),
    FONT_NAME_SYMBOL("fontNameSymbol", "fns"),
    FONT_SCALE("fontScale", null),
    FONT_SCHEME("fontScheme", null),
    FONT_SIZE("fontSize", null),
    FONT_SIZE_ASIAN("fontSizeAsian", null),
    FONT_SIZE_COMPLEX("fontSizeComplex", null),
    FOOTER_ROW("footerRow", null),
    FORE_COLOR("foreColor", null),
    FORM_FIELD_TYPE("formFieldType", null),
    FORMAT("format", null),
    FORMAT_CODE("formatCode", null),
    FORMAT_ID("formatId", null),
    FORMULA("formula", null),
    FROM("from", null),
    G("g", null),
    GD_LIST("gdList", null),
    GD_REF_ANG("gdRefAng", null),
    GD_REF_R("gdRefR", null),
    GD_REF_X("gdRefX", null),
    GD_REF_Y("gdRefY", null),
    GEOMETRY("geometry", null),
    GRADIENT("gradient", null),
    GRID_COLOR("gridColor", null),
    GRID_POSITION("gridPosition", null),
    GRID_SPAN("gridSpan", null),
    GROUP("group", null),
    GTE("gte", null),
    H("h", null),
    HEAD_END_LENGTH("headEndLength", null),
    HEAD_END_TYPE("headEndType", null),
    HEAD_END_WIDTH("headEndWidth", null),
    HEADER_ROW("headerRow", null),
    HEADERS("headers", null),
    HEIGHT("height", null),
    HIDDEN("hidden", null),
    HIDE_BUTTON("hideButton", null),
    HIDE_BUTTONS("hideButtons", null),
    HORZ_OVERFLOW("horzOverflow", null),
    HOST_DATA("hostData", null),
    HR("hr", null),
    ICON_SET("iconSet", null),
    ID("id", null),
    IGNORE_EMPTY("ignoreEmpty", null),
    IMAGE("image", null),
    IMAGE_DATA("imageData", null),
    IMAGE_URL("imageUrl", null),
    INDENT("indent", null),
    INDENT_FIRST_LINE("indentFirstLine", null),
    INDENT_LEFT("indentLeft", null),
    INDENT_RIGHT("indentRight", null),
    INDEX("index", null),
    INFO_TEXT("infoText", null),
    INFO_TITLE("infoTitle", null),
    INITIALS("initials", null),
    INLINE("inline", null),
    INSERT_DEFAULT_CELLS("insertDefaultCells", null),
    INSERT_MODE("insertMode", null),
    INSERTED("inserted", null),
    INSTRUCTION("instruction", null),
    INTERVALS("intervals", null),
    IR("ir", null),
    IS("is", null),
    IS_DATE("isDate", null),
    IS_EXPR("isExpr", null),
    IS_EXTRUSION_OK("isExtrusionOk", null),
    IS_FOOTER("isFooter", null),
    IS_HEADER("isHeader", null),
    IS_ROTATE_WITH_SHAPE("isRotateWithShape", null),
    IS_SCALED("isScaled", null),
    IS_SLIDE_NUM("isSlideNum", null),
    IS_STROKE("isStroke", null),
    ITALIC("italic", null),
    ITALIC_ASIAN("italicAsian", null),
    ITALIC_COMPLEX("italicComplex", null),
    KEEP_CONTENT("keepContent", null),
    L("l", null),
    L1("l1", null),
    L2("l2", null),
    L3("l3", null),
    L4("l4", null),
    L5("l5", null),
    L6("l6", null),
    L7("l7", null),
    L8("l8", null),
    L9("l9", null),
    LABEL("label", null),
    LABEL_FOLLOWED_BY("labelFollowedBy", null),
    LANGUAGE("language", null),
    LANGUAGE_BIDI("languageBidi", null),
    LANGUAGE_EA("languageEa", null),
    LAST_COL("lastCol", null),
    LAST_ROW("lastRow", null),
    LAYOUT("layout", null),
    LEFT("left", null),
    LEGEND("legend", null),
    LENGTH("length", null),
    LETTER_SPACING("letterSpacing", null),
    LEVEL("level", null),
    LEVEL_PIC_BULLET_URI("levelPicBulletUri", null),
    LEVEL_TEXT("levelText", null),
    LINE("line", null),
    LINE_HEIGHT("lineHeight", null),
    LINE_REDUCTION("lineReduction", null),
    LINE_SELECTION("lineSelection", null),
    LINK("link", null),
    LIST("list", null),
    LIST_DEFINITION("listDefinition", null),
    LIST_ID("listId", null),
    LIST_LABEL_HIDDEN("listLabelHidden", null),
    LIST_LEVEL("listLevel", null),
    LIST_LEVEL_POSITION_AND_SPACE_MODE("listLevelPositionAndSpaceMode", null),
    LIST_OVERRIDE_START_VALUE("listOverrideStartValue", null),
    LIST_START_VALUE("listStartValue", null),
    LIST_STYLE("listStyle", null),
    LIST_STYLE_ID("listStyleId", null),
    LIST_STYLES("listStyles", null),
    LOCKED("locked", null),
    MARGIN_BOTTOM("marginBottom", null),
    MARGIN_FOOTER("marginFooter", null),
    MARGIN_HEADER("marginHeader", null),
    MARGIN_LEFT("marginLeft", null),
    MARGIN_RIGHT("marginRight", null),
    MARGIN_TOP("marginTop", null),
    MARKER_FILL("markerFill", null),
    MARKER_BORDER("markerBorder", null),
    MAX("max", null),
    MAX_ANG("maxAng", null),
    MAX_R("maxR", null),
    MAX_X("maxX", null),
    MAX_Y("maxY", null),
    MENTION_ID("mentionId", null),
    MENTIONS("mentions", null),
    MERGE_VERT("mergeVert", null),
    MERGED("merged", null),
    METH("meth", null),
    MIN("min", null),
    MIN_ANG("minAng", null),
    MIN_FRAME_HEIGHT("minFrameHeight", "mfh"),
    MIN_LABEL_DISTANCE("minLabelDistance", null),
    MIN_LABEL_WIDTH("minLabelWidth", null),
    MIN_R("minR", null),
    MIN_X("minX", null),
    MIN_Y("minY", null),
    MODIFIED("modified", null),
    MR("mr", null),
    NAME("name", "n"),
    NAMES("names", null),
    NEW_NAME("newName", null),
    NBC("nbc", null),
    NBS("nbs", null),
    NC("nc", null),
    NCS("ncs", null),
    NEW_LABEL("newLabel", null),
    NEXT_STYLE_ID("nextStyleId", null),
    NO_AUTO_RESIZE("noAutoResize", null),
    NO_FILL("noFill", null),
    NO_GROUP("noGroup", null),
    NO_LINE("noLine", null),
    NO_MOVE("noMove", null),
    NO_PROOF("noProof", null),
    NO_RESIZE("noResize", null),
    NO_ROTATION("noRotation", null),
    NO_SELECT("noSelect", null),
    NORTH_EAST_CELL("northEastCell", null),
    NORTH_WEST_CELL("northWestCell", null),
    NULL_DATE("nullDate", null),
    NUM_TYPE("numType", null),
    NUMBER("number", null),
    NUMBER_FORMAT("numberFormat", null),
    OFF_X("offX", null),
    OFF_Y("offY", null),
    OLDINDEX("oldindex", null),
    OLDTARGET("oldtarget", null),
    ONLY_MARKER("onlyMarker", null),
    OP("op", null),
    OPL("opl", null),
    ORIENTATION("orientation", null),
    OSN("osn", null),
    OTHER("other", null),
    OUTLINE_LEVEL("outlineLevel", null),
    P("p", null),
    P0("p0", null),
    P1("p1", null),
    P2("p2", null),
    PADDING_BOTTOM("paddingBottom", null),
    PADDING_LEFT("paddingLeft", null),
    PADDING_RIGHT("paddingRight", null),
    PADDING_TOP("paddingTop", null),
    PAGE("page", null),
    PAGE_BREAK_AFTER("pageBreakAfter", null),
    PAGE_BREAK_BEFORE("pageBreakBefore", null),
    PANOSE1("panose1", null),
    PARA_STYLE("paraStyle", null),
    PARAGRAPH("paragraph", "pa"),
    PARENT("parent", null),
    PARENTTARGET("parenttarget", null),
    PARENT_ID("parentId", null),
    PATH_FILL_BOTTOM("pathFillBottom", null),
    PATH_FILL_LEFT("pathFillLeft", null),
    PATH_FILL_RIGHT("pathFillRight", null),
    PATH_FILL_TOP("pathFillTop", null),
    PATH_LIST("pathList", null),
    PATH_TYPE("pathType", null),
    PATTERN("pattern", null),
    PH_INDEX("phIndex", null),
    PH_SIZE("phSize", null),
    PH_TYPE("phType", null),
    PITCH("pitch", null),
    POS("pos", null),
    POSITION("position", null),
    PRESENTATION("presentation", "pr"),
    PRESET_SHAPE("presetShape", null),
    PRINT_ORIENTATION("printOrientation", null),
    PRIORITY("priority", null),
    PROTECT("protect", null),
    PROVIDER_ID("providerId", null),
    PTS("pts", null),
    R("r", null),
    R1("r1", null),
    R2("r2", null),
    RANGE("range", null),
    RANGES("ranges", null),
    RECT_ALIGNMENT("rectAlignment", null),
    REF("ref", null),
    REFERENCE_ROW("referenceRow", null),
    REMOVED("removed", null),
    REPRESENTATION("representation", null),
    RESTORABLE("restorable", null),
    RIGHT("right", null),
    ROTATE_WITH_SHAPE("rotateWithShape", null),
    ROTATION("rotation", null),
    ROTATION_X("rotationX", null),
    ROTATION_Y("rotationY", null),
    ROW("row", null),
    ROW_TOTAL_BEFORE("rowTotalBefore", null),
    ROWS("rows", null),
    S("s", null),
    SCROLL_BOTTOM("scrollBottom", null),
    SCROLL_LEFT("scrollLeft", null),
    SCROLL_RIGHT("scrollRight", null),
    SCROLL_TOP("scrollTop", null),
    SELECTED_RANGES("selectedRanges", null),
    SERIES("series", null),
    SHAPE("shape", "sh"),
    SHEET("sheet", null),
    SHEET_NAME("sheetName", null),
    SHEETS("sheets", null),
    SHOW_DROP_DOWN("showDropDown", null),
    SHOW_ERROR("showError", null),
    SHOW_GRID("showGrid", null),
    SHOW_ONLY_VISIBLE_CELLS_DATA("sovcd", null),
    SHOW_INFO("showInfo", null),
    SI("si", null),
    SIZE("size", null),
    SIZE_EXCEEDED("sizeExceeded", null),
    SLIDE("slide", null),
    SLIDE_PANE_WIDTH("slidePaneWidth", null),
    SORT("sort", null),
    SOUTH_EAST_CELL("southEastCell", null),
    SOUTH_WEST_CELL("southWestCell", null),
    SPACE("space", null),
    SPACE_BEFORE("spaceBefore", null),
    SPACING_AFTER("spacingAfter", null),
    SPACING_BEFORE("spacingBefore", null),
    SPLIT_HEIGHT("splitHeight", null),
    SPLIT_MODE("splitMode", null),
    SPLIT_WIDTH("splitWidth", null),
    SR("sr", null),
    ST_ANG("stAng", null),
    STACKING("stacking", null),
    START("start", "o"),
    START_AT("startAt", null),
    START_GRID("startGrid", null),
    START_ID("startId", null),
    START_INDEX("startIndex", null),
    STOP("stop", null),
    STRETCH_X("stretchX", null),
    STRETCH_Y("stretchY", null),
    STRETCHING("stretching", null),
    STRIKE("strike", null),
    STRIPSET_SIZE("stripesetSize", null),
    STYLE("style", null),
    STYLE_ID("styleId", "st"),
    STYLE_NAME("styleName", "sn"),
    SW_ANG("swAng", null),
    T("t", null),
    TAB_STOP_POSITION("tabStopPosition", null),
    TAB_STOPS("tabStops", null),
    TABLE("table", "tb"),
    TABLE_GRID("tableGrid", null),
    TABLE_NAMES("tableNames", null),
    TAIL_END_LENGTH("tailEndLength", null),
    TAIL_END_TYPE("tailEndType", null),
    TAIL_END_WIDTH("tailEndWidth", null),
    TARGET("target", "ta"),
    TEXT("text", "w"),
    TEXT_ALIGN("textAlign", null),
    TEXT_PATH("textPath", null),
    TEXT_RECT("textRect", null),
    TEXT_WRAP_MODE("textWrapMode", null),
    TEXT_WRAP_SIDE("textWrapSide", null),
    THEME_NAME("themeName", null),
    TILING("tiling", null),
    TITLE("title", null),
    TO("to", null),
    TOP("top", null),
    TOP_LEFT("topLeft", null),
    TOP_RIGHT("topRight", null),
    TRANSFORMATIONS("transformations", null),
    TRANSPARENCY("transparency", null),
    TYPE("type", "ty"),
    U("u", null),
    UI_PRIORITY("uiPriority", null),
    UNDERLINE("underline", null),
    UNKNOWN_KEY("unknownKey", null),
    UNLOCKED("unlocked", null),
    URL("url", null),
    USED_LANGUAGES("usedLanguages", null),
    USED_LANGUAGES_BIDI("usedLanguagesBidi", null),
    USED_LANGUAGES_EA("usedLanguagesEa", null),
    USER_ID("userId", null),
    V("v", null),
    VALUE("value", null),
    VALUE1("value1", null),
    VALUE2("value2", null),
    VALUES("values", null),
    VARY_COLORS("varyColors", null),
    VERT("vert", null),
    VERT_ALIGN("vertAlign", null),
    VERT_OVERFLOW("vertOverflow", null),
    VERTICAL_POS("verticalPos", null),
    VERTICAL_REL("verticalRel", null),
    VISIBLE("visible", null),
    WHOLE_TABLE("wholeTable", null),
    WIDTH("width", null),
    WORD_WRAP("wordWrap", null),
    WR("wr", null),
    WRAP_TEXT("wrapText", null),
    X("x", null),
    Y("y", null),
    Z_AXIS("zAxis", null),
    ZOOM("zoom", null);

    private String value;
    final private String longName;
    final private String shortName;

    private static Map<String, OCKey> nameToEnumMap = Collections.unmodifiableMap(initializeNameToEnumMap(true));

    private OCKey(String longName, String shortName) {
        this.longName = longName;
        this.shortName = shortName;
        this.value = shortName!=null ? shortName : longName;
    }

    public String value() {
        return value;
    }

    public String value(boolean useLongName) {
        return useLongName ? longName : value;
    }

    public static OCKey fromValue(String val) {
        final OCKey key = nameToEnumMap.get(val);
        if(key==null) {
            return UNKNOWN_KEY;
        }
        return key;
    }

    private static Map<String, OCKey> initializeNameToEnumMap(boolean useShortName) {
        final Map<String, OCKey> mMap = new HashMap<String, OCKey>();
        for (OCKey s : OCKey.values()) {
            s.value = s.longName;
            if(useShortName && s.shortName!=null) {
                s.value = s.shortName;
            }
            mMap.put(s.value, s);
        }
        return mMap;
    }

    public static void debugOnly(boolean useShortName) {
        nameToEnumMap = Collections.unmodifiableMap(initializeNameToEnumMap(useShortName));
    }

    public static OCKey fromShortNameValue(String val) {
        for(OCKey value:OCKey.values()) {
            if(value.shortName.equals(val)) {
                return value;
            }
        }
        return OCKey.UNKNOWN_KEY;
    }

    public static OCKey fromLongNameValue(String val) {
        for(OCKey value:OCKey.values()) {
            if(value.longName.equals(val)) {
                return value;
            }
        }
        return OCKey.UNKNOWN_KEY;
    }
}
